// vite.config.js
import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import vueDevTools from 'vite-plugin-vue-devtools';
import { createSvgIconsPlugin } from 'vite-plugin-svg-icons'
import path from 'path'
export default defineConfig(({ command, mode }) => {
  // Load environment variables based on `mode` in the current working directory.
  const env = loadEnv(mode, process.cwd());
  console.log("env", env)
  return {
    server: {
      host: true, // host设置为true才可以使用network的形式，以ip访问项目
      port: 5180, // 端口号
      https: false,
      open: false, // true 自动打开浏览器自动打开浏览器
      cors: true, // 跨域设置允许
      strictPort: true,  // 如果端口已占用直接退出
      proxy: {
        '/api': {
          target: env.VITE_APP_BASE_API, // 使用环境变量中的 API 地址
          changeOrigin: true,
          rewrite: (path) => path.replace(/^\/api/, '/api'),
        },
      },
    },
    plugins: [
      vue(),
      vueDevTools(),
      createSvgIconsPlugin({
        iconDirs: [path.resolve(process.cwd(), 'src/assets/icons')],
        symbolId: 'icon-[dir]-[name]',
      }),
    ],
    resolve: {
      alias: {
        '@': '/src', // 使用字符串路径简化别名配置
      },
    },
    define: {
      __APP_ENV__: JSON.stringify(env.ENV),
      __APP_BASE_API__: JSON.stringify(env.VITE_APP_BASE_API), // 将 API 地址定义为全局变量
    },
  };
});
